double_tap_exit library

Classes

DoubleTap
DoubleBack, wrap a widget to use it child : widget message : to show on toast waitToSecondPressed (optional) if you want to wait longer condition and conditionFail, if you want show at spesific condition